module.exports = defineTest({
	description: 'skips a dead branch (j)'
});
